LIGHT_BULB = 'light_bulb'
BINARY_SWITCH = 'binary_switch'
SENSOR_POD = 'sensor_pod'
LOCK = 'lock'
EGG_TRAY = 'eggtray'
GARAGE_DOOR = 'garage_door'
POWER_STRIP = 'powerstrip'
SHADE = 'shades'
SIREN = 'siren'
KEY = 'key'
PIGGY_BANK = 'piggybank'
SMOKE_DETECTOR = 'smoke_detector'
THERMOSTAT = 'thermostat'
HUB = 'hub'
FAN = 'fan'

DEVICE_ID_KEYS = {
    BINARY_SWITCH: 'binary_switch_id',
    EGG_TRAY: 'eggtray_id',
    GARAGE_DOOR: 'garage_door_id',
    LIGHT_BULB: 'light_bulb_id',
    LOCK: 'lock_id',
    POWER_STRIP: 'powerstrip_id',
    SENSOR_POD: 'sensor_pod_id',
    SHADE: 'shade_id',
    SIREN: 'siren_id',
    KEY: 'key_id',
    PIGGY_BANK: 'piggy_bank_id',
    SMOKE_DETECTOR: 'smoke_detector_id',
    THERMOSTAT: 'thermostat_id',
    HUB: 'hub_id',
    FAN: 'fan_id'
}
